@@ -111,6 +111,31 @@ setClass("ur.za", representation(y="vector",
                                  testreg="ANY"),
          contains="urca")
 
+setClassUnion("otherornull", c("ANY", "character", "integer", "matrix", "vector", "NULL")) 
+
+setClass("sumurca", representation(classname="character",
+                                   test.name="character",
+                                   testreg="ANY",
+                                   teststat="otherornull",
+                                   cval="otherornull",
+                                   bpoint="otherornull",
+                                   signif="otherornull",
+                                   model="otherornull",
+                                   type="otherornull",
+                                   auxstat="otherornull",
+                                   lag="otherornull",
+                                   H="otherornull",
+                                   A="otherornull",
+                                   lambda="otherornull",
+                                   pval="otherornull",
+                                   V="otherornull",
+                                   W="otherornull",
+                                   P="otherornull")
+         )
+                                   
+
+
+
 #
 # Functions for unit root tests and cointegration analysis
 #
@@ -745,8 +770,7 @@ cajolst <- function (x, trend = TRUE, K = 2, season = NULL)
       colnames(cval) <- c("10%", "5%", "1%")
       rownames(cval) <- c(paste("r <= ", (arrsel - 1):1, " |", sep = ""), "r = 0  |")
     }
-    new("ca.jo", x = x, Z0 = Z0, Z1 = Z1, ZK = ZK, type = type, 
-        model = model, const = FALSE, lag = K, P = arrsel, 
+    new("ca.jo", x = x, Z0 = Z0, Z1 = Z1, ZK = ZK, type = type,         model = model, const = FALSE, lag = K, P = arrsel, 
         season = season, dumvar = NULL, cval = cval, teststat = as.vector(teststat), 
         lambda = lambda, Vorg = Vorg, V = V, W = W, PI = PI, 
         DELTA = DELTA, GAMMA = GAMMA, R0 = R0, RK = RK, bp = tau.bp, 
@@ -1224,195 +1248,224 @@ setMethod("show", "ur.za", show.urca)
 setMethod("show", "ur.ers", show.urca)
 
 setMethod("summary", "ur.ers", function(object){
-  title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  cat("Test of type", object@type, "\ndetrending of series", object@model, "\n")
-  cat("\n")
-  if(!is.null(object@testreg)){
-    print(object@testreg)
-    cat('\n')
-  }
-  cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
-  cat('\n')
-  cat('Critical values of', object@type, "are:\n")
-  print(object@cval)
-  cat('\n')
+  return(new("sumurca", classname="ur.ers", test.name=object@test.name, testreg=object@testreg, teststat=object@teststat, cval=object@cval, bpoint=NULL, signif=NULL, model=object@model, type=object@type, auxstat=NULL, lag=NULL, H=NULL, A=NULL, lambda=NULL, pval=NULL, V=NULL, W=NULL, P=NULL))  
 })
 
 setMethod("summary", "ca.jo", function(object){
-  title <- paste("#", object@test.name, "#", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  cat("Test type:", object@type, ",", object@model, "\n")
-  cat("\n")
-  cat("Eigenvalues (lambda):\n")
-  print(object@lambda)
-  cat('\n')
-  if(!(is.null(object@cval))){
-    res1 <- as.matrix(round(object@teststat, 2))
-    colnames(res1) <- "test"
-    result <- cbind(res1, object@cval) 
-    cat("Values of teststatistic \& critical values of test:\n")
-    cat("\n")
-    print(result)
-    cat("\n")
-  }else{
-    cat("Values of test statistic\n")
-    cat("\n")
-    result <- as.matrix(object@teststat)
-    rownames(result) <- c(paste("r <= ", (object@P-1):1, " |",sep=""), "r = 0  |")
-    print(result)
-    cat("\n")
-  }
-  cat("Eigenvectors, normalised to first column:\n")
-  cat("(These are the cointegration relations)\n")
-  cat("\n")
-  print(object@V)
-  cat("\n")
-  cat("Weights W:\n")
-  cat("(This is the loading matrix)\n")
-  cat("\n")
-  print(object@W)
-  cat("\n")
+  return(new("sumurca", classname="ca.jo", test.name=object@test.name, testreg=NULL, teststat=object@teststat, cval=object@cval, bpoint=NULL, signif=NULL, model=object@model, type=object@type, auxstat=NULL, lag=NULL, H=NULL, A=NULL, lambda=object@lambda, pval=NULL, V=object@V, W=object@W, P=object@P))
 })
 
 setMethod("summary", "cajo.test", function(object){
-  title <- paste("#", object@test.name, "#", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  cat(object@type, "\n")
-  cat("\n")
-  cat("The VECM has been estimated subject to: \n")
-  cat("beta=H*phi and/or alpha=A*psi\n")
-  if(!is.null(object@H)){
-    cat("\n")
-    print(object@H)
-    cat("\n")
-  }
-  if(!is.null(object@A)){
-    cat("\n")
-    print(object@A)
-    cat("\n")
-  }
-  cat("Eigenvalues of restricted VAR (lambda):\n")
-  print(round(object@lambda, 4))
-  cat('\n')
-  cat("The value of the likelihood ratio test statistic:\n")
-  cat(round(object@teststat, 2), "distributed as chi square with", object@pval[2], "df.\n")
-  cat("The p-value of the test statistic is:", round(object@pval[1], 2), "\n")
-  cat("\n")
-  cat("Eigenvectors, normalised to first column\n")
-  cat("of the restricted VAR:\n")
-  cat("\n")
-  print(round(object@V, 4))
-  cat("\n")
-  cat("Weights W of the restricted VAR:\n")
-  cat("\n")
-  print(round(object@W, 4))
-  cat("\n")
+  return(new("sumurca", classname="cajo.test", test.name=object@test.name, testreg=NULL, teststat=object@teststat, cval=NULL, bpoint=NULL, signif=NULL, model=NULL, type=object@type, auxstat=NULL, lag=NULL, H=object@H, A=object@A, lambda=object@lambda, pval=object@pval, V=object@V, W=object@W, P=NULL))
 })
 
 setMethod("summary", "ur.kpss", function(object){
-  title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  cat('Test is of type:', object@type, 'with', object@lag, 'lags. \n')
-  cat('\n')
-  cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
-  cat('\n')
-  cat('Critical value for a significance level of: \n')
-  print(object@cval)
-  cat('\n')
+  return(new("sumurca", classname="ur.kpss", test.name=object@test.name, testreg=NULL, teststat=object@teststat, cval=object@cval, bpoint=NULL, signif=NULL, model=NULL, type=object@type, auxstat=NULL, lag=object@lag, H=NULL, A=NULL, lambda=NULL, pval=NULL, V=NULL, W=NULL, P=NULL))
 })
 
 setMethod("summary", "ca.po", function(object){
-  title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  cat("Test of type", object@type, "\ndetrending of series", object@model, "\n")
-  cat("\n")
-  print(object@testreg)
-  cat('\n')
-  cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
-  cat('\n')
-  cat('Critical values of', object@type, "are:\n")
-  print(object@cval)
-  cat('\n')
+  return(new("sumurca", classname="ca.po", test.name=object@test.name, testreg=object@testreg, teststat=object@teststat, cval=object@cval, bpoint=NULL, signif=NULL, model=object@model, type=object@type, auxstat=NULL, lag=NULL, H=NULL, A=NULL, lambda=NULL, pval=NULL, V=NULL, W=NULL, P=NULL))
 })
 
 setMethod("summary", "ur.pp", function(object){
-  title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  cat('Test regression', object@model, '\n')
-  cat('\n')
-  print(object@testreg)
-  cat('\n')
-  cat('Value of test-statistic, type:', object@type,' is:', round(object@teststat, 4), '\n')
-  cat('\n')
-  print(object@auxstat)
-  cat('\n')
-  cat('Critical values for Z statistics: \n')
-  print(object@cval)
-  cat('\n')
+  return(new("sumurca", classname="ur.pp", test.name=object@test.name, testreg=object@testreg, teststat=object@teststat, cval=object@cval, bpoint=NULL, signif=NULL, model=object@model, type=object@type, auxstat=object@auxstat, lag=NULL, H=NULL, A=NULL, lambda=NULL, pval=NULL, V=NULL, W=NULL, P=NULL))
 })
   
 setMethod("summary", "ur.sp", function(object){
-  title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  print(object@testreg)
-  cat('\n')
-  cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
-  cat('Critical value for a significance level of', object@signif, '\n')
-  cat('is:', object@cval, '\n')
-  cat('\n')
+  return(new("sumurca", classname="ur.sp", test.name=object@test.name, testreg=object@testreg, teststat=object@teststat, cval=object@cval, bpoint=NULL, signif=object@signif, model=NULL, type=NULL, auxstat=NULL, lag=NULL, H=NULL, A=NULL, lambda=NULL, pval=NULL, V=NULL, W=NULL, P=NULL))
 })
 
 setMethod("summary", "ur.za", function(object){
-  title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
-  row <- paste(rep("#", nchar(title)), collapse="")
-  cat("\n")
-  cat(row, "\n")
-  cat(title, "\n")
-  cat(row, "\n")
-  cat("\n")
-  print(object@testreg)
-  cat('\n')
-  cat('Teststatistic:', round(object@teststat, 4), '\n')
-  cat('Critical values: 0.01=', object@cval[1], '0.05=', object@cval[2], '0.1=', object@cval[3], '\n')
-  cat('\n')
-  cat('Potential break point at position:', object@bpoint, '\n')
-  cat('\n')
+  return(new("sumurca", classname="ur.za", test.name=object@test.name, testreg=object@testreg, teststat=object@teststat, cval=object@cval, bpoint=object@bpoint, signif=NULL, model=NULL, type=NULL, auxstat=NULL, lag=NULL, H=NULL, A=NULL, lambda=NULL, pval=NULL, V=NULL, W=NULL, P=NULL))
+})
+
+setMethod("show", "sumurca", function(object){
+  if(object@classname=="ur.za"){
+    title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
+    row <- paste(rep("#", nchar(title)), collapse="")
+    cat("\n")
+    cat(row, "\n")
+    cat(title, "\n")
+    cat(row, "\n")
+    cat("\n")
+    print(object@testreg)
+    cat('\n')
+    cat('Teststatistic:', round(object@teststat, 4), '\n')
+    cat('Critical values: 0.01=', object@cval[1], '0.05=', object@cval[2], '0.1=', object@cval[3], '\n')
+    cat('\n')
+    cat('Potential break point at position:', object@bpoint, '\n')
+    cat('\n')
+    invisible(object)
+  }else if(object@classname=="ur.sp"){
+    title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
+    row <- paste(rep("#", nchar(title)), collapse="")
+    cat("\n")
+    cat(row, "\n")
+    cat(title, "\n")
+    cat(row, "\n")
+    cat("\n")
+    print(object@testreg)
+    cat('\n')
+    cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
+    cat('Critical value for a significance level of', object@signif, '\n')
+    cat('is:', object@cval, '\n')
+    cat('\n')
+    invisible(object)
+  }else if(object@classname=="ur.pp"){
+    title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
+    row <- paste(rep("#", nchar(title)), collapse="")
+    cat("\n")
+    cat(row, "\n")
+    cat(title, "\n")
+    cat(row, "\n")
+    cat("\n")
+    cat('Test regression', object@model, '\n')
+    cat('\n')
+    print(object@testreg)
+    cat('\n')
+    cat('Value of test-statistic, type:', object@type,' is:', round(object@teststat, 4), '\n')
+    cat('\n')
+    print(object@auxstat)
+    cat('\n')
+    cat('Critical values for Z statistics: \n')
+    print(object@cval)
+    cat('\n')
+    invisible(object)
+  }else if(object@classname=="ca.po"){
+    title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
+    row <- paste(rep("#", nchar(title)), collapse="")
+    cat("\n")
+    cat(row, "\n")
+    cat(title, "\n")
+    cat(row, "\n")
+    cat("\n")
+    cat("Test of type", object@type, "\ndetrending of series", object@model, "\n")
+    cat("\n")
+    print(object@testreg)
+    cat('\n')
+    cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
+    cat('\n')
+    cat('Critical values of', object@type, "are:\n")
+    print(object@cval)
+    cat('\n')
+    invisible(object)
+    }else if(object@classname=="ur.kpss"){
+      title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
+      row <- paste(rep("#", nchar(title)), collapse="")
+      cat("\n")
+      cat(row, "\n")
+      cat(title, "\n")
+      cat(row, "\n")
+      cat("\n")
+      cat('Test is of type:', object@type, 'with', object@lag, 'lags. \n')
+      cat('\n')
+      cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
+      cat('\n')
+      cat('Critical value for a significance level of: \n')
+      print(object@cval)
+      cat('\n')
+      invisible(object)
+    }else if(object@classname=="cajo.test"){
+      title <- paste("#", object@test.name, "#", sep=" ")
+      row <- paste(rep("#", nchar(title)), collapse="")
+      cat("\n")
+      cat(row, "\n")
+      cat(title, "\n")
+      cat(row, "\n")
+      cat("\n")
+      cat(object@type, "\n")
+      cat("\n")
+      cat("The VECM has been estimated subject to: \n")
+      cat("beta=H*phi and/or alpha=A*psi\n")
+      if(!is.null(object@H)){
+        cat("\n")
+        print(object@H)
+        cat("\n")
+      }
+      if(!is.null(object@A)){
+        cat("\n")
+        print(object@A)
+        cat("\n")
+      }
+      cat("Eigenvalues of restricted VAR (lambda):\n")
+      print(round(object@lambda, 4))
+      cat('\n')
+      cat("The value of the likelihood ratio test statistic:\n")
+      cat(round(object@teststat, 2), "distributed as chi square with", object@pval[2], "df.\n")
+      cat("The p-value of the test statistic is:", round(object@pval[1], 2), "\n")
+      cat("\n")
+      cat("Eigenvectors, normalised to first column\n")
+      cat("of the restricted VAR:\n")
+      cat("\n")
+      print(round(object@V, 4))
+      cat("\n")
+      cat("Weights W of the restricted VAR:\n")
+      cat("\n")
+      print(round(object@W, 4))
+      cat("\n")
+      invisible(object)
+    }else if(object@classname=="ca.jo"){
+      title <- paste("#", object@test.name, "#", sep=" ")
+      row <- paste(rep("#", nchar(title)), collapse="")
+      cat("\n")
+      cat(row, "\n")
+      cat(title, "\n")
+      cat(row, "\n")
+      cat("\n")
+      cat("Test type:", object@type, ",", object@model, "\n")
+      cat("\n")
+      cat("Eigenvalues (lambda):\n")
+      print(object@lambda)
+      cat('\n')
+      if(!(is.null(object@cval))){
+        res1 <- as.matrix(round(object@teststat, 2))
+        colnames(res1) <- "test"
+        result <- cbind(res1, object@cval)
+        cat("Values of teststatistic \& critical values of test:\n")
+        cat("\n")
+        print(result)
+        cat("\n")
+      }else{
+        cat("Values of test statistic\n")
+        cat("\n")
+        result <- as.matrix(object@teststat)
+        rownames(result) <- c(paste("r <= ", (object@P-1):1, " |",sep=""), "r = 0  |")
+        print(result)
+        cat("\n")
+        invisible(x)
+      }
+      cat("Eigenvectors, normalised to first column:\n")
+      cat("(These are the cointegration relations)\n")
+      cat("\n")
+      print(object@V)
+      cat("\n")
+      cat("Weights W:\n")
+      cat("(This is the loading matrix)\n")
+      cat("\n")
+      print(object@W)
+      cat("\n")
+      invisible(object)
+    }else if(object@classname=="ur.ers"){
+      title <- paste("#", object@test.name, "Unit Root Test #", sep=" ")
+      row <- paste(rep("#", nchar(title)), collapse="")
+      cat("\n")
+      cat(row, "\n")
+      cat(title, "\n")
+      cat(row, "\n")
+      cat("\n")
+      cat("Test of type", object@type, "\ndetrending of series", object@model, "\n")
+      cat("\n")
+      if(!is.null(object@testreg)){
+        print(object@testreg)
+        cat('\n')
+      }
+      cat('Value of test-statistic is:', round(object@teststat, 4), '\n')
+      cat('\n')
+      cat('Critical values of', object@type, "are:\n")
+      print(object@cval)
+      cat('\n')
+      invisible(object)
+    }
 })
 
 setMethod("plot", signature(x="ur.ers", y="missing"), function(x){
